@@ -27,11 +27,11 @@ sub calculate {
 	my $s = $l-1;
 
 	while (--$l >= 0) {
-		$p->setx($p->getx + @Bin[$l-$s]*@{@Pointxyz[$l]}[0]);
-		$p->sety($p->gety + @Bin[$l-$s]*@{@Pointxyz[$l]}[1]);
-		$p->setz($p->getz + @Bin[$l-$s]*@{@Pointxyz[$l]}[2]);
+		$p->setx($p->getx + @Bin[$l-$s]*@{@Pointxyz[$l-$s]}[0]);
+		$p->sety($p->gety + @Bin[$l-$s]*@{@Pointxyz[$l-$s]}[1]);
+		$p->setz($p->getz + @Bin[$l-$s]*@{@Pointxyz[$l-$s]}[2]);
 
-		### FIXME $s += 2;
+		$s -= 2; 
 	}
 
 	return $p;
@@ -46,9 +46,9 @@ sub calculate_for_z_order {
 	my $s = $l-1;
 
 	while (--$l >= 0) {
-		$z += @Bin[$l-$s]*@{@Pointzyz[$l]}[2];
+		$z += @Bin[$l-$s]*@{@Pointzyz[$l-$s]}[2];
 	
-		### FIXME $s += 2;
+		$s -= 2;
 	}
 
 	return $z;
