@@ -8,6 +8,18 @@ sub new {
 	bless $self, $class;
 }
 
+sub xyz {
+	my $self = shift;
+
+	my @array = ();
+
+	push(@array, $self->{x});
+	push(@array, $self->{y});
+	push(@array, $self->{z});
+
+	return @array;
+} 
+
 sub getx {
 	my $self = shift;
 
